@@ -204,7 +204,7 @@ class CountryCodeParser(object):
 
     def get(self, country_code):
         try:
-            return self._data[country_code]
+            return self._data.get(country_code, country_code)
         except KeyError:
             raise KeyError('Not found country name for code "%s"'
                            % country_code)
